@@ -3,6 +3,7 @@
 
 (use-modules (srfi srfi-1))
 (use-modules (nyacc lang c99 parser))
+(use-modules (nyacc lang c99 cxeval))
 (use-modules (nyacc lang c99 xparser))
 (use-modules (nyacc lang c99 cpp))
 (use-modules (nyacc lang c99 pprint))
@@ -121,7 +122,7 @@
 	      "typedef int *bla_t[2];\n"
 	      "bla_t foo(bla_t (*)(bla_t));\n"))
        (indx 2)
-       (tree (parse-c99x "\"\""))
+       ;;(tree (parse-c99x "\"\""))
        ;;(tree (parse-string code))
        ;;(tree (parse-file "xxx.c"))
        ;;(udict (c99-trans-unit->udict tree))
@@ -132,7 +133,12 @@
        ;;(mdecl (udecl->mspec udecl))
        ;;(decl (and=> ((sxpath `((decl ,indx))) tree) car))
        ;;(xdecl (expand-typerefs udecl udict '((struct . "foo"))))
+       ;;(exp (parse-c99x "1+2"))
+       (exp (parse-c99x "sizeof(\"abc\")"))
+       (val (eval-c99-cx exp))
        )
+  (ppsx exp)
+  (ppsx val)
   ;;(display code)
   ;;(ppsx tree)
   ;;(ppsx decl)
