@@ -1,29 +1,29 @@
 ;;; nyacc/lang/dxl/cnvt.scm -- convert dxl to javascript
-;;;
-;;; Copyright (C) 2015,2016 Matthew R. Wette
-;;;
-;;; This program is free software: you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by 
-;;; the Free Software Foundation, either version 3 of the License, or 
-;;; (at your option) any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of 
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+;; Copyright (C) 2015-2018 Matthew R. Wette
+;;
+;; This library is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU Lesser General Public
+;; License as published by the Free Software Foundation; either
+;; version 3 of the License, or (at your option) any later version.
+;;
+;; This library is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; Lesser General Public License for more details.
+;;
+;; You should have received a copy of the GNU Lesser General Public License
+;; along with this library; if not, see <http://www.gnu.org/licenses/>
 
 ;;(add-to-load-path (string-append (getcwd) "/../../../nyacc.git/module"))
 ;;(add-to-load-path (string-append (getcwd) "/../../../nyacc.git/examples"))
 (add-to-load-path (string-append (getcwd) "/../.."))
 
 (use-modules (nyacc lang util))
+(use-modules (nyacc lang sx-match))
 (use-modules (nyacc lang dxl mach))
 (use-modules (nyacc lang dxl mach))
 (use-modules (nyacc lang javascript pprint))
-(use-modules (sxml match))
 (use-modules (sxml fold))
 (use-modules ((srfi srfi-1) #:select (fold append-reverse)))
 (use-modules (ice-9 pretty-print))
