@@ -1,19 +1,19 @@
 ;;; lang/matlab/mach.scm
-;;;
-;;; Copyright (C) 2015,2017 Matthew R. Wette
-;;;
-;;; This program is free software: you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation, either version 3 of the License, or
-;;; (at your option) any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+;; Copyright (C) 2015,2017-2018 Matthew R. Wette
+;;
+;; This library is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU Lesser General Public
+;; License as published by the Free Software Foundation; either
+;; version 3 of the License, or (at your option) any later version.
+;;
+;; This library is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; Lesser General Public License for more details.
+;;
+;; You should have received a copy of the GNU Lesser General Public License
+;; along with this library; if not, see <http://www.gnu.org/licenses/>.
 
 ;; matlab parser
 ;; 1) does NOT parse lone expressions of the form [ 1, 2] => syntax error
@@ -108,7 +108,7 @@
      (non-comment-statement))
     (non-comment-statement
      (term ($$ #f))
-     (lval-expr "(" expr-list ")" term ($$ `(call ,$1 ,(tl->list $3))))
+     (lval-expr "(" expr-list ")" term ($$ `(call-stmt ,$1 ,(tl->list $3))))
      (lval-expr "=" expr term ($$ `(assn ,$1 ,$3)))
      ("[" lval-expr-list "]" "=" ident "(" ")" term
       ($$ `(multi-assign ,(tl->list $2) ,$5 (expr-list))))
