@@ -39,18 +39,10 @@
   #:use-module ((srfi srfi-1) #:select (fold fold-right remove lset-union
 					     lset-intersection lset-difference))
   #:use-module ((srfi srfi-9) #:select (define-record-type))
+  #:use-module (srfi srfi-43)
   #:use-module (nyacc util)
   #:use-module (nyacc version)
   )
-(cond-expand
-  (guile-2
-   (use-modules (srfi srfi-43)))
-  (guile
-   (use-modules (ice-9 optargs))
-   (use-modules (ice-9 syncase))
-   (export lalr-spec-1 parse-precedence parse-grammar
-	   parse-rhs-list parse-rhs)
-   (use-modules (nyacc compat18))))
 
 ;; @deffn proxy-? sym rhs
 ;; @example
