@@ -2,9 +2,11 @@
 
 ;; Copyright (C) 2016,2017 Matthew R. Wette
 ;; 
-;; This software is covered by the GNU GENERAL PUBLIC LICENCE, Version 3,
-;; or any later version published by the Free Software Foundation.  See
-;; the file COPYING included with the this distribution.
+;; This library is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU Lesser General Public
+;; License as published by the Free Software Foundation; either
+;; version 3 of the License, or (at your option) any later version.
+;; See the file COPYING.LESSER included with the this distribution.
 
 (define c99-act-v
   (vector
@@ -377,6 +379,10 @@
    (lambda ($2 $1 . $rest) (tl-append $1 $2))
    ;; struct-declaration-list => struct-declaration-list lone-comment
    (lambda ($2 $1 . $rest) (tl-append $1 $2))
+   ;; struct-declaration-list => ";"
+   (lambda ($1 . $rest) (make-tl 'field-list))
+   ;; struct-declaration-list => struct-declaration-list ";"
+   (lambda ($2 $1 . $rest) $1)
    ;; struct-declaration => specifier-qualifier-list struct-declarator-list...
    (lambda ($4 $3 $2 $1 . $rest)
      (if (pair? $4)
@@ -832,6 +838,15 @@
    (lambda ($1 . $rest) `(float ,$1))
    ;; constant => '$chlit
    (lambda ($1 . $rest) `(char ,$1))
+   ;; constant => '$chlit/L
+   (lambda ($1 . $rest)
+     `(char (@ (type "wchar_t")) ,$1))
+   ;; constant => '$chlit/u
+   (lambda ($1 . $rest)
+     `(char (@ (type "char16_t")) ,$1))
+   ;; constant => '$chlit/U
+   (lambda ($1 . $rest)
+     `(char (@ (type "char32_t")) ,$1))
    ;; string-literal => '$string
    (lambda ($1 . $rest) (make-tl 'string $1))
    ;; string-literal => string-literal '$string
