@@ -2,9 +2,11 @@
 
 ;; Copyright (C) 2016,2017 Matthew R. Wette
 ;; 
-;; This software is covered by the GNU GENERAL PUBLIC LICENCE, Version 3,
-;; or any later version published by the Free Software Foundation.  See
-;; the file COPYING included with the this distribution.
+;; This library is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU Lesser General Public
+;; License as published by the Free Software Foundation; either
+;; version 3 of the License, or (at your option) any later version.
+;; See the file COPYING.LESSER included with the this distribution.
 
 (define cpp-act-v
   (vector
@@ -99,6 +101,15 @@
    (lambda ($1 . $rest) `(fixed ,$1))
    ;; primary-expression => '$chlit
    (lambda ($1 . $rest) `(char ,$1))
+   ;; primary-expression => '$chlit/L
+   (lambda ($1 . $rest)
+     `(char (@ (type "wchar_t")) ,$1))
+   ;; primary-expression => '$chlit/u
+   (lambda ($1 . $rest)
+     `(char (@ (type "char16_t")) ,$1))
+   ;; primary-expression => '$chlit/U
+   (lambda ($1 . $rest)
+     `(char (@ (type "char32_t")) ,$1))
    ;; primary-expression => "defined" "(" '$ident ")"
    (lambda ($4 $3 $2 $1 . $rest) `(defined ,$3))
    ;; primary-expression => "defined" '$ident
